<?php
// Version: 1.1.5; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1.5';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $language, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<!--[if lte IE 6]><link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/ie.css?fin11" /><![endif]-->
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';
	
	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
	{
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		$options['collapse_header_ic'] = !empty($_COOKIE['upshrinkIC']);
	}

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>
</head>
<body id="page_bg">';

// wrapper div defines style width. (in the css)

	echo '
	<div id="wrapper">
		<div id="header-l">
			<div id="header-r">
				<div id="header">';
					if (empty($settings['custom_logo']))
						echo '
						<div id="logo-bg"><a href="'.$scripturl.'" title="">', $context['forum_name'], '</a></div>';
					if (!empty($settings['custom_logo']))
						echo '<div id="logo"><a href="'.$scripturl.'" title=""></a></div>';
    				echo '
					<div id="mainmenu"> ';
						// Show the menu here, according to the menu sub template.
						template_menu();
						
						// If they're a guest - this time ask them to either register or login - lazy bums...
						if ($context['user']['is_guest'])
						{
						echo '
						<div class="menu_column">			
							<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
								<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" style="margin: 8px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
								<input type="text" name="user" style="margin-bottom: 4px;" size="10" />
								<input type="password" name="passwrd" style="margin-bottom: 4px;" size="10" /><br />
								<select name="cookielength">
									<option value="60">', $txt['smf53'], '</option>
									<option value="1440">', $txt['smf47'], '</option>
									<option value="10080">', $txt['smf48'], '</option>
									<option value="43200">', $txt['smf49'], '</option>
									<option value="-1" selected="selected">', $txt['smf50'], '</option>
								</select>
								<input type="submit" value="', $txt[34], '" />
								<input type="hidden" name="hash_passwrd" value="" />
							</form>', $txt['logintxt1'], '<br />', $txt['logintxt2'], '<br />
						</div>';
						}
	 	 			echo '
					</div>';
					if ($context['user']['is_logged'])
					{
					if (!empty($context['user']['avatar']))
						{
							// Display user avatar in header if logged in					
							// Resize large avatars (if selected under "current theme") for the header
							if(!empty($settings['top_avatar_resize']))
							{
								$context['user']['avatar']['image'] = strtr($context['user']['avatar']['image'], array("class=\"avatar\"" => "class=\"avatar_r\""));
							}
							echo '<div class="avatar_box">', $context['user']['avatar']['image'], '</div>';
						}
					}
				echo'
				</div>
			</div>
		</div>
<div class="clr"></div>
<div id="shadow-l">
	<div id="shadow-r">
	
<table width="100%" cellpadding="0" cellspacing="0" border="0">
	<tr>';
	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']))
	{
	echo'
	 	<td class="news">
			<h3>' ,$txt['newshd'], '</h3>
			', $context['random_news_line'], '
		</td>';
	}
	echo'
	<td class="showcase">
		' , showcase(), '
	</td>
	</tr>
</table>

		<div id="mainbody">';
		
if ($context['user']['is_admin'])
{
	if (empty($txt['necessary_to_translate']))
	echo '
		<div style="margin: 0 2ex 2ex 2ex; padding: 2ex; border: 2px dashed #cc3344; color: black; background-color: #e7e7f7;">
			<div style="float: left; width: 2ex; font-size: 2em; color: red;">!!</div>
			<b style="text-decoration: underline;">Attention of lightning-dk theme:</b><br />
			<div style="padding-left: 6ex;">
				You have to create &quot;<b>Modifications.<span style="color: red;"><acronym title="Name of language that you are using">' , $language , '</acronym></span>.php</b>&quot; in the &quot;<b>languages</b>&quot; directory ( <i>', $settings['theme_url'], '/languages/</i> ) of your lightning-dk theme.<br /><br />
				Duplicate the &quot;<i>Modifications.english.php</i>&quot; of the &quot;languages&quot; directory of lightning-dt. Next, rename it according to the language for which you use the file. 
			</div>
		</div>';
}

}

// The main content should go here.  A table is used because IE 6 just can't handle a div [Bollocks ;)].
function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;


// Show the "Powered by" and "Valid" logos, as well as the copyright.  Remember, the copyright must be somewhere!
	echo '
	<div id="footer">
	', theme_copyright(), '<br /><br />
			<a href="http://themes.simplemachines.org/" title="theme title" target="_blank">lightning-dk</a> Theme by <a href="http://padexx.de/" title="Author of the theme" target="_blank">padexx</a>
	</div>
</div>
</div>
</div>
<div id="footer2_l">
	<div id="footer2_r">
		<div id="footer2">
			&nbsp;
		</div>
	</div>
</div>
</div>';

// Show the load time?
	if ($context['show_load_time'])
		echo '
		<div class="smalltext" style="color: #ffba26; text-align: center; margin: 10px;">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</div> ';

// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>
</body></html>';
} 
function theme_linktree()
{
	global $context, $settings, $options , $txt;

	echo '<div class="breadcrumb">', $txt['you are here: '] ,'<span class="pathway">';
	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			// Show the link, including a URL if it should have one.
			echo $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="pathway">' . $tree['name'] . '</a>' : $tree['name'] , ' &raquo; ';
		else
			echo $tree['name'];

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

	}

	echo '</span></div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

// Start of the tab section.

echo'
<div class="menu_column">';

// Show the [home] button.
	echo ($current_action=='home' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'home' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '">&gt; ' , $txt[103] , '</a>
				</div>' , $current_action == 'home' ? '' : '';
	
// Show the [help] button.
	echo ($current_action == 'help' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'help' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=help">&gt; ' , $txt[119] , '</a>
				</div>' , $current_action == 'help' ? '' : '';

// How about the [search] button?
	if ($context['allow_search'])
		{
		echo ($current_action == 'search' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'search' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=search;advanced">&gt; ' , $txt[182] , '</a>
				</div>' , $current_action == 'search' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}

echo'
</div>'; //END menu column 1

echo'
<div class="menu_column">';

// The [calendar]!
	if ($context['allow_calendar'])
		{
		echo ($current_action == 'calendar' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'calendar' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=calendar">&gt; ' , $txt['calendar24'] , '</a>
				</div>' , $current_action == 'calendar' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}
		
// the [member] list button
	if ($context['allow_memberlist'])
		{
		echo ($current_action == 'mlist' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'mlist' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=mlist">&gt; ' , $txt[331] , '</a>
				</div>' , $current_action == 'mlist' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}
		
// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		{
		echo ($current_action == 'profile' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'profile' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=profile">&gt; ' , $txt[79] , '</a>
				</div>' , $current_action == 'profile' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}
		
echo'
</div>'; //END menu column 2

echo'
<div class="menu_column">';

// Go to PM center... [pm]
	if ($context['user']['is_logged'] && $context['allow_pm'])
		{
		echo ($current_action == 'pm' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'pm' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=pm">&gt; ' , $txt['pm_short'] , ' ', $context['user']['unread_messages'] > 0 ? '[<strong>'. $context['user']['unread_messages'] . '</strong>]' : '' , '</a>
				</div>' , $current_action == 'pm' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}
		
// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		{
		echo ($current_action == 'admin' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'admin' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=admin">&gt; ' , $txt[2] , '</a>
				</div>' , $current_action == 'admin' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}
		
// If the user is a guest, also show [register] button.
	if ($context['user']['is_guest'])
		{
		echo ($current_action == 'register' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="maintab_' , $current_action == 'register' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=register">&gt; ' , $txt[97] , '</a>
				</div>' , $current_action == 'register' ? '' : '';
		}
	else
		{
		echo'
		<div class="maintab_back"><a href="#">&nbsp;</a></div>';
		}
			
echo'
</div>'; //END menu column 3

echo'
<div class="login_column">';

// If the user is a guest, show [login] button.
	if ($context['user']['is_guest'])
		echo ($current_action == 'login' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="logintab_' , $current_action == 'login' ? 'active_back' : 'back' , '">
					<a id="showmoobox" href="', $scripturl, '?action=login">L<br />O<br />G<br />I<br />N</a>
				</div>' , $current_action == 'login' ? '' : '';

// Otherwise, they might want to [logout]...
	if ($context['user']['is_logged'])
		echo ($current_action == 'logout' || $context['browser']['is_ie4']) ? '' : '' , '
				<div class="logintab_' , $current_action == 'logout' ? 'active_back' : 'back' , '">
					<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">L<br />O<br />G<br />O<br />U<br />T</a>
				</div>' , $current_action == 'logout' ? '' : '';

echo'
</div>';	

// The end of tab section.

}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons text buttons
	if (empty($settings['imagebuttons']))
	{
		foreach ($button_strip as $key => $value)
		{
			if (isset($value['test']) && empty($context[$value['test']]))
			{
				unset($button_strip[$key]);
				continue;
			}
			elseif (!isset($buttons[$key]) || $force_reset)
				$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';

			$button_strip[$key] = $buttons[$key];
		}

		if (empty($button_strip))
			return '<td>&nbsp;</td>';

		echo '
			<td class="buttons">', implode('</td><td class="buttons">', $button_strip) , '</td>';
	}
	// Create the image buttons instead of the text buttons (if selected under "current theme")
	else
	{
		if (empty($button_strip))
			return '';

		foreach ($button_strip as $key => $value)
		{
			if (isset($value['test']) && empty($context[$value['test']]))
			{
				unset($button_strip[$key]);
				continue;
			}
			elseif (!isset($buttons[$key]) || $force_reset)
				$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . ($value['lang'] ? $context['user']['language'] . '/' : '') . $value['image'] . '" alt="' . $txt[$value['text']] . '" border="0" />' : $txt[$value['text']]) . '</a>';

			$button_strip[$key] = $buttons[$key];
		}

		echo '
			<td ', $custom_td, '>', implode($context['menu_separator'], $button_strip) , '</td>';
	}
}

function showcase()
{
	global $settings, $buttons, $context, $txt, $scripturl;
	
	echo'
	<h3>' ,$txt['showcasehd'], '</h3>';
	
	// personal info etc.
	
	// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])
	{
		echo '
   	<div class="userinfo">';
		echo '<b>', $txt['hello_member_ndt'], ' ', $context['user']['name'], '</b>';

		echo '<ul>';
		// Only tell them about their messages if they can read their messages!
		if ($context['allow_pm'])
			echo '<li>', $txt[152], ' <a href="', $scripturl, '?action=pm">', $context['user']['messages'], ' ', $context['user']['messages'] != 1 ? $txt[153] : $txt[471], '</a> ', $context['user']['unread_messages'], ' ', $context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1'];
		echo '.</li>';

		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '<li><b>', $txt[616], '</b></li>';

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '<li>', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '</li>';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '<li>
							', $txt['totalTimeLogged1'], '<br />';

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '</li>';
		}

		echo '<li><a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a></li>
					<li><a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a></li>
		     </ul>
		</div>';
  }

	echo '
		<div class="searchfield">
			<form action="', $scripturl, '?action=search2" method="post" style="margin: 4px 0;">
				<input type="text" name="search" value="" size="30" style="margin-bottom: 4px;"  />&nbsp;
				<input type="submit" name="submit" value="', $txt[182], '" style="margin-bottom: 4px;"  /><br />
				<a href="', $scripturl, '?action=search;advanced">', $txt['smf298'], '</a>
				<input type="hidden" name="advanced" value="0" />';

				// Search within current topic?
				if (!empty($context['current_topic']))
				echo '
					<input type="hidden" name="topic" value="', $context['current_topic'], '" />';

   			// If we're on a certain board, limit it to this board ;).
				elseif (!empty($context['current_board']))
				echo '
					<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';
				
				echo '
			</form>
			<br />					
			<b>', $context['common_stats']['total_posts'], '</b> ', $txt[95], ' ', $txt['smf88'], ' <b>', $context['common_stats']['total_topics'], '</b> ', $txt[64], '- ', $txt[525], ' <span style="white-space: nowrap;"><b>', $context['common_stats']['total_members'], '</b> ', $txt[19], '</span> -
			', $txt[656], ': <b> ', $context['common_stats']['latest_member']['link'], '</b><br /><br />', $context['current_time'],'
		</div>
		<div class="clr"></div>';
}

?>